@@ -4,7 +4,7 @@ from deezer.gw import GW
 from deezer.api import API
 from deezer.errors import DeezerError, WrongLicense, WrongGeolocation
 
-__version__ = "1.1.2"
+__version__ = "1.2.3"
 
 class TrackFormats():
     """Number associtation for formats"""
@@ -18,11 +18,10 @@ class TrackFormats():
     LOCAL   = 0
 
 class Deezer:
-    def __init__(self, accept_language=None):
+    def __init__(self):
         self.http_headers = {
             "User-Agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) " \
-                          "Chrome/79.0.3945.130 Safari/537.36",
-            "Accept-Language": accept_language
+                          "Chrome/79.0.3945.130 Safari/537.36"
         }
         self.session = requests.Session()
 
@@ -34,12 +33,6 @@ class Deezer:
         self.api = API(self.session, self.http_headers)
         self.gw = GW(self.session, self.http_headers)
 
-    def get_accept_language(self):
-        return self.http_headers['Accept-Language']
-
-    def set_accept_language(self, lang):
-        self.http_headers['Accept-Language'] = lang
-
     def get_session(self):
         return {
             'logged_in': self.logged_in,
@@ -58,6 +51,7 @@ class Deezer:
         self.session.cookies.update(data['cookies'])
 
     def login(self, email, password, re_captcha_token, child=0):
+        if child: child = int(child)
         # Check if user already logged in
         user_data = self.gw.get_user_data()
         if user_data['USER']['USER_ID'] == 0:
@@ -88,6 +82,7 @@ class Deezer:
 
     def login_via_arl(self, arl, child=0):
         arl = arl.strip()
+        if child: child = int(child)
         cookie_obj = requests.cookies.create_cookie(
             domain='.deezer.com',
             name='arl',
@@ -108,19 +103,21 @@ class Deezer:
 
     def _post_login(self, user_data):
         self.childs = []
-        family = user_data["USER"]["MULTI_ACCOUNT"]["ENABLED"]
+        family = user_data["USER"]["MULTI_ACCOUNT"]["ENABLED"] and not user_data["USER"]["MULTI_ACCOUNT"]["IS_SUB_ACCOUNT"]
         if family:
             childs = self.gw.get_child_accounts()
             for child in childs:
-                self.childs.append({
-                    'id': child["USER_ID"],
-                    'name': child["BLOG_NAME"],
-                    'picture': child.get("USER_PICTURE", ""),
-                    'license_token': user_data["USER"]["OPTIONS"]["license_token"],
-                    'can_stream_hq': user_data["USER"]["OPTIONS"]["web_hq"] or user_data["USER"]["OPTIONS"]["mobile_hq"],
-                    'can_stream_lossless': user_data["USER"]["OPTIONS"]["web_lossless"] or user_data["USER"]["OPTIONS"]["mobile_lossless"],
-                    'country': user_data["COUNTRY"]
-                })
+                if child['EXTRA_FAMILY']['IS_LOGGABLE_AS']:
+                    self.childs.append({
+                        'id': child["USER_ID"],
+                        'name': child["BLOG_NAME"],
+                        'picture': child.get("USER_PICTURE", ""),
+                        'license_token': user_data["USER"]["OPTIONS"]["license_token"],
+                        'can_stream_hq': user_data["USER"]["OPTIONS"]["web_hq"] or user_data["USER"]["OPTIONS"]["mobile_hq"],
+                        'can_stream_lossless': user_data["USER"]["OPTIONS"]["web_lossless"] or user_data["USER"]["OPTIONS"]["mobile_lossless"],
+                        'country': user_data["USER"]["OPTIONS"]["license_country"],
+                        'language': user_data["USER"]["SETTING"]["global"]["language"]
+                    })
         else:
             self.childs.append({
                 'id': user_data["USER"]["USER_ID"],
@@ -129,27 +126,36 @@ class Deezer:
                 'license_token': user_data["USER"]["OPTIONS"]["license_token"],
                 'can_stream_hq': user_data["USER"]["OPTIONS"]["web_hq"] or user_data["USER"]["OPTIONS"]["mobile_hq"],
                 'can_stream_lossless': user_data["USER"]["OPTIONS"]["web_lossless"] or user_data["USER"]["OPTIONS"]["mobile_lossless"],
-                'country': user_data["COUNTRY"]
+                'country': user_data["USER"]["OPTIONS"]["license_country"],
+                'language': user_data["USER"]["SETTING"]["global"]["language"]
             })
 
     def change_account(self, child_n):
         if len(self.childs)-1 < child_n: child_n = 0
         self.current_user = self.childs[child_n]
         self.selected_account = child_n
+        self.http_headers["Accept-Language"] = self.current_user['language']
 
         return (self.current_user, self.selected_account)
 
     def get_track_url(self, track_token, track_format):
-        return self.get_tracks_url([track_token, ], track_format)
+        tracks = self.get_tracks_url([track_token, ], track_format)
+        if len(tracks) > 0:
+            if isinstance(tracks[0], DeezerError):
+                raise tracks[0]
+            else:
+                return tracks[0]
+        return None
 
     def get_tracks_url(self, track_tokens, track_format):
         if not isinstance(track_tokens, list):
             track_tokens = [track_tokens, ]
         if not self.current_user['license_token']:
-            return None
+            return []
         if track_format == "FLAC" and not self.current_user['can_stream_lossless'] or format == "MP3_320" and not self.current_user['can_stream_hq']:
             raise WrongLicense(format)
 
+        result = []
         try:
             request = self.session.post(
                 "https://media.deezer.com/v1/get_url",
@@ -168,13 +174,17 @@ class Deezer:
             request.raise_for_status()
             response = request.json()
         except requests.exceptions.HTTPError:
-            return None
+            return []
 
         if len(response.get('data', [])):
-            if 'errors' in response['data'][0]:
-                if response['data'][0]['errors'][0]['code'] == 2002:
-                    raise WrongGeolocation(self.current_user['country'])
-                raise DeezerError(json.dumps(response))
-            if response['data'][0]['media']:
-                return response['data'][0]['media'][0]['sources'][0]['url']
-        return None
+            for data in response['data']:
+                if 'errors' in data:
+                    if data['errors'][0]['code'] == 2002:
+                        result.append(WrongGeolocation(self.current_user['country']))
+                    else:
+                        result.append(DeezerError(json.dumps(response)))
+                if data['media']:
+                    result.append(data['media'][0]['sources'][0]['url'])
+                else:
+                    result.append(None)
+        return result
